<?php

/**
 * This class handles the adding of styled and unstyled
 * Header (text strings) in the DOM structure.
 *  
 * $Id: Heading.class.php,v 1.1.1.1 2006/09/17 15:41:38 Andi Exp $
 *
 * @license    http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 * @copyright  Copyright in 2006 by Andi Hotz
 * @copyright  GNU Lesser General Public License
 * @author     Andi Hotz
 * @version    $Revision: 1.1.1.1 $
 * @package    ODFLib
 * @subpackage odfNodes
 * @since      0.0.1
 */
class Heading{
	
	private $dom;
	
	public function __construct(DOMDocument $dom){
		$this->dom=$dom;
	}
	/**
	 * Add a new paragraph with the paragraph $text
	 * after $afterNode
	 * @param string $text paragraph text
	 * @param int $outlineLevel level of the Heading
	 * @param DOMNode $afterNode After this node the paragraph
	 * is added in the DOM structure
	 * @return The inserted node
	 */
	public function addHeading($text,$outlineLevel = 1,DOMNode $afterNode){
		if (empty ($text)) {
			$head = $this->dom->createElement('text:h');
		} else {
			$head = $this->dom->createElement('text:h', $text);
		}
		$head->setAttribute('text:outline-level', $outlineLevel);
		require_once('Replace.class.php');
		return Replace::insertAfter($this->dom,$afterNode,$head);
		
	}
	
	/**
	 * Add a new paragraph with the paragraph $text
	 * after $afterNode. A style is spezialized
	 * @param string $text paragraph text
	 * @param int $outlineLevel level of the Heading
	 * @param DOMNode $afterNode After this node the paragraph
	 * is added in the DOM structure
	 * @param string $style of the paragraph.
	 * @return The inserted node
	 */
	public function addStyledHeading($text,$outlineLevel = 1,DOMNode $afterNode,$style){
		if (empty ($text)) {
			$head = $this->dom->createElement('text:p');
		} else {
			$head = $this->dom->createElement('text:p', $text);
		}
		$head->setAttribute('text:outline-level', $outlineLevel);
		$head->setAttribute('text:style-name', $style);
		require_once('Replace.class.php');
		return Replace::insertAfter($this->dom,$afterNode,$head);
		
	}
	
}
?>